pub fn diff_str(a: &str, b: &str) -> Result<Option<Difference>, Error>Expand description
Parse a and b as semver::Versions and return their diff.
Errors
Returns the semver::Error from the first input that fails to parse.
pub fn diff_str(a: &str, b: &str) -> Result<Option<Difference>, Error>Parse a and b as semver::Versions and return their diff.
Returns the semver::Error from the first input that fails to parse.